pub trait Intake: Send + Sync {
// Required methods
fn intake_document<'life0, 'async_trait>(
&'life0 self,
request: IntakeRequest,
) -> Pin<Box<dyn Future<Output = Result<IntakeResult>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn extract_ocr<'life0, 'async_trait>(
&'life0 self,
request: Request,
) -> Pin<Box<dyn Future<Output = Result<Result>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Defines the behavior required from a intake participant in the tools workflow.
Required Methods
Sourcefn intake_document<'life0, 'async_trait>(
&'life0 self,
request: IntakeRequest,
) -> Pin<Box<dyn Future<Output = Result<IntakeResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn intake_document<'life0, 'async_trait>(
&'life0 self,
request: IntakeRequest,
) -> Pin<Box<dyn Future<Output = Result<IntakeResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Resolves the request into source-grounded lookup evidence without editing provider records or contacting customers.
Sourcefn extract_ocr<'life0, 'async_trait>(
&'life0 self,
request: Request,
) -> Pin<Box<dyn Future<Output = Result<Result>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn extract_ocr<'life0, 'async_trait>(
&'life0 self,
request: Request,
) -> Pin<Box<dyn Future<Output = Result<Result>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Resolves the request into source-grounded lookup evidence without editing provider records or contacting customers.